searchData={"items":[{"type":"module","title":"Renewex","doc":"The `Renewex` module provides functionality for parsing [Renew](http://renew.de) source files (*.rnw).","ref":"Renewex.html"},{"type":"function","title":"Renewex.parse_document/1","doc":"Parses the content of a .rnw file saved by [Renew](http://renew.de).","ref":"Renewex.html#parse_document/1"},{"type":"function","title":"Parameters - Renewex.parse_document/1","doc":"- `input`: The content of an .rnw file as string","ref":"Renewex.html#parse_document/1-parameters"},{"type":"function","title":"Returns - Renewex.parse_document/1","doc":"- `{:ok, root, refs}`: On success, returns the root of the parsed document tree and a list of references.\n  - `{:error, reason}`: On failure, returns an error tuple with the reason for failure.","ref":"Renewex.html#parse_document/1-returns"},{"type":"function","title":"Renewex.serialize_document/1","doc":"Convert a document into a serialized binary string according to the [Renew](http://renew.de) (*.rnw) file format.","ref":"Renewex.html#serialize_document/1"},{"type":"function","title":"Parameters - Renewex.serialize_document/1","doc":"- `document`: The renew document to serialize","ref":"Renewex.html#serialize_document/1-parameters"},{"type":"function","title":"Returns - Renewex.serialize_document/1","doc":"- `{:ok, string}`: On success, returns the serialized document as string.\n  - `{:error, reason}`: On failure, returns an error tuple with the reason for failure.","ref":"Renewex.html#serialize_document/1-returns"},{"type":"module","title":"Renewex.Aliases","doc":"This module defines aliases for [Renew](http://renew.de) class names.\r\n\r\nSome [Renew](http://renew.de) classes have been renamed at some point in time. \r\nTo be able to load both old and new renew file versions this module keeps a mapping from old to the corresponding\r\nclass names.","ref":"Renewex.Aliases.html"},{"type":"function","title":"Renewex.Aliases.resolve_alias/1","doc":"This function converts an old [Renew](http://renew.de) class name to its corresponding new class name.\r\nIn case the class name has never been renamed the original name is returned.","ref":"Renewex.Aliases.html#resolve_alias/1"},{"type":"function","title":"Parameters - Renewex.Aliases.resolve_alias/1","doc":"- `input`: Fully qualified name of a [Renew](http://renew.de) Java class","ref":"Renewex.Aliases.html#resolve_alias/1-parameters"},{"type":"function","title":"Returns - Renewex.Aliases.resolve_alias/1","doc":"- The fully qualified new name of the class if it has been renamed\r\n- The given name otherwise.","ref":"Renewex.Aliases.html#resolve_alias/1-returns"},{"type":"module","title":"Renewex.Document","doc":"`Renewex.Document` captures the concept of a full [Renew](http://renew.de) document as described by the content of an `*.rnw` file.","ref":"Renewex.Document.html"},{"type":"function","title":"Renewex.Document.__struct__/0","doc":"A `Renewex.Document` consists of:\r\n- `version`: The file format version (see `Renewex.Grammar.latest_version/0`),\r\n- `root`: a root node (a `Renewex.Storable.__struct__/0` or a `{:ref, ...}` to a `Renewex.Storable.__struct__/0`), \r\n- `refs`: a list of `Renewex.Storable.__struct__/0` that can reference each other via index into this list,\r\n- `size`: an optional tuple `{x, y, width, height}` (or `nil`) describing the window dimensions of the Renew application window when the file was saved.","ref":"Renewex.Document.html#__struct__/0"},{"type":"function","title":"Renewex.Document.new/4","doc":"Initialize a new `Renewex.Document` struct.","ref":"Renewex.Document.html#new/4"},{"type":"function","title":"Parameters - Renewex.Document.new/4","doc":"- `version`: The file format version (see `Renewex.Grammar.latest_version/0`)\r\n- `root`: a root node (a `Renewex.Storable.__struct__/0` or a `{:ref, ...}` to a `Renewex.Storable.__struct__/0`), \r\n- `refs`: a list of `Renewex.Storable.__struct__/0` that can reference each other via index into this list,\r\n- `size`: an optional tuple `{x, y, width, height}` (or `nil`) describing the window dimensions of the Renew application window when the file was saved.","ref":"Renewex.Document.html#new/4-parameters"},{"type":"module","title":"Renewex.Grammar","doc":"This module defines the grammar to parse [Renew](http://renew.de) `*.rnw` files.\r\n\r\nThe Renew grammar is version dependent and depends on the Java class hierarchy defined in renew.\r\n\r\nThis module defines a struct to describe the class hierarchy and some specialized function to parse specific classes.","ref":"Renewex.Grammar.html"},{"type":"function","title":"Renewex.Grammar.__struct__/0","doc":"This struct describes the class hierarchy for a specific version of [Renew](http://renew.de) that should be applied as grammar.\r\nThe `version` field is an integer between -1 (the original renew version) and 11 (the newest Renew version at the time of writing this comment).\r\n\r\nThe `hierarchy` field contains a `Map` from Java class names to class descriptions. It mirrors the Java class definitions defined in Renew.\r\nThis is done because the grammar that is used for reading and writing Renew files is implicitly defined via the Java implementation.\r\nIn order to match the grammar exactly this Java class hierarchy is reenacted.","ref":"Renewex.Grammar.html#__struct__/0"},{"type":"function","title":"Renewex.Grammar.latest_version/0","doc":"The latest version of Renew to be used preferably.","ref":"Renewex.Grammar.html#latest_version/0"},{"type":"function","title":"Renewex.Grammar.min_version/0","doc":"The earliest version of Renew to be used for files that do not specify their own version explicitly.","ref":"Renewex.Grammar.html#min_version/0"},{"type":"function","title":"Renewex.Grammar.new/1","doc":"Constructs a new grammar struct for the given version.","ref":"Renewex.Grammar.html#new/1"},{"type":"function","title":"Renewex.Grammar.parse/3","doc":"Applies a specific rul to the current parser state.","ref":"Renewex.Grammar.html#parse/3"},{"type":"function","title":"Parameters - Renewex.Grammar.parse/3","doc":"- parser: the current state of the parser\r\n- rule: the name of the parser rule to apply. The parse rule is a java class name that must be defined in the grammars hierarchy.\r\n- into: an `Storable` struct into which the parsed values shall be appended","ref":"Renewex.Grammar.html#parse/3-parameters"},{"type":"function","title":"Returns - Renewex.Grammar.parse/3","doc":"- `{:ok, Renew.Storable{into | fields: parsed_fields}, next_parse_state}` if the rule was applied successfully.\r\n  Where `parsed_fields` contain the values that have been parsed by the rule and next_parse_state is the \r\n  state of the parser after having consumed the tokens processed by the parse rule\r\n- `{:error, reason, next_parse_state}` if the rule could not be applied for some reason.","ref":"Renewex.Grammar.html#parse/3-returns"},{"type":"function","title":"Renewex.Grammar.serialize/3","doc":"Serialize the given `field_values` according to the given grammar `rule`.","ref":"Renewex.Grammar.html#serialize/3"},{"type":"function","title":"Parameters - Renewex.Grammar.serialize/3","doc":"- `serializer`: The serializer into which output the result is appended.\r\n- `rule`: The name of the grammar rule to be used for serializtation. The actual grammar definition comes from the `serializer`.\r\n- `field_values`: The map of values to be serialized.","ref":"Renewex.Grammar.html#serialize/3-parameters"},{"type":"function","title":"Resturns - Renewex.Grammar.serialize/3","doc":"Either `{:ok, new_serializer}` if the serializtation was successful.\r\nOtheriwse `{:error, reason}` if it failed for some `reason`.","ref":"Renewex.Grammar.html#serialize/3-resturns"},{"type":"function","title":"Renewex.Grammar.should_skip_super/2","doc":"Checks if for the given grammar and given class name the skip skip_super flag is set.\r\nIf the skip_super flag is set, the grammar rules of the parent class shall not be applied during parsing.\r\nThis corresponds to NOT calling `super.read()` in the java implementation of the class.","ref":"Renewex.Grammar.html#should_skip_super/2"},{"type":"function","title":"Parameters - Renewex.Grammar.should_skip_super/2","doc":"- grammar: the current state of the parser\r\n- rule: name of the grammar rule","ref":"Renewex.Grammar.html#should_skip_super/2-parameters"},{"type":"function","title":"Returns - Renewex.Grammar.should_skip_super/2","doc":"- if the the :skip_user flag has been set for the given rule in the given grammar.","ref":"Renewex.Grammar.html#should_skip_super/2-returns"},{"type":"module","title":"Renewex.Hierarchy","doc":"The grammar for parsing a [Renew](http://renew.de) `*.rnw` file is defined by the \r\nobject oriented class hierarchy of java classes in the original Java Renew implementation.\r\n\r\nIn order to parse all Renew `*.rnw` files correctly, this hierarchical model has to be reproduced \r\nas desribed in the Renewex.Grammar module. \r\n\r\nThis module provides utility functions to query the hierarchy of a given `Renewex.Grammar`. For example you can query if Java \r\nclass of a given name is defined inside the hierarchy or if some class a sub class of another class.","ref":"Renewex.Hierarchy.html"},{"type":"function","title":"Renewex.Hierarchy.all_rules/1","doc":"Get a list of all classes defined in the grammars hierarchy.","ref":"Renewex.Hierarchy.html#all_rules/1"},{"type":"function","title":"Renewex.Hierarchy.get_super/2","doc":"Get the name of the super class of the given class inside the given hierarchy.","ref":"Renewex.Hierarchy.html#get_super/2"},{"type":"function","title":"Renewex.Hierarchy.implementors_of/2","doc":"The the list of all classes that are defined to implement a given interface inside the hierarchy of the grammar.","ref":"Renewex.Hierarchy.html#implementors_of/2"},{"type":"function","title":"Renewex.Hierarchy.interfaces_of/2","doc":"Get the list of all interfaces that a given class is defined to implement by the hierarchy of the given grammar.","ref":"Renewex.Hierarchy.html#interfaces_of/2"},{"type":"function","title":"Renewex.Hierarchy.is_defined/2","doc":"Check if a class of a given name is defined inside the hierarchy of the given grammar.","ref":"Renewex.Hierarchy.html#is_defined/2"},{"type":"function","title":"Renewex.Hierarchy.is_implementation_of/3","doc":"Check if `subtype` is an implementation of given `interface_or_class` or if subtype is identical to the given `interface_or_class`.","ref":"Renewex.Hierarchy.html#is_implementation_of/3"},{"type":"function","title":"Renewex.Hierarchy.is_subtype_of/3","doc":"Check if one class is a subtype of another class or interface.","ref":"Renewex.Hierarchy.html#is_subtype_of/3"},{"type":"function","title":"Renewex.Hierarchy.roots/1","doc":"Get a list of all classes in the grammars hierarchy that have no super class.","ref":"Renewex.Hierarchy.html#roots/1"},{"type":"function","title":"Renewex.Hierarchy.subtypes_of/2","doc":"Get a list of all supetypes of one or many given supertypes defined in the grammar hierarchy.","ref":"Renewex.Hierarchy.html#subtypes_of/2"},{"type":"module","title":"Renewex.Parser","doc":"This module implements the core of the parser for reading [Renew](http://renew.de) `*.rnw` files.\r\nThe grammar to be used for parsing is defined by `Renewex.Grammar`.\r\n\r\nThe counter part for generating/serializing [Renew](http://renew.de) `*.rnw` files is defined in `Renewex.Serializer`.\r\n\r\nThis `Renewex.Parser` manages the overall parser state and provides function to process the whole \r\ntoken stream coming from an `*.rnw` file.","ref":"Renewex.Parser.html"},{"type":"function","title":"Renewex.Parser.__struct__/0","doc":"The state of the parser consists of 4 fields:\r\n\r\n- `grammar`: The grammar definition to be used for serialization.\r\n- `tokens`: The list of yet to be processed tokens.\r\n- `ref_stack`: A stack (list) of already parsed `Renewex.Storable.__struct__/0` structs. This is used to allow for `Renewex.Storable.__struct__/0`s to \r\n  reference each other by index, as required by the [Renew](http://renew.de) file format. \r\n  Yet during parsing this stack is in reverse order (to allow fast pushes that the front of the list). \r\n    It has be reversed for the referencing indices to be resolved correctly.\r\n- `ref_count`: The number of elements inside the `ref_stack`. \r\n  This is used to to quick calculations without counting the elements in `ref_stack`.","ref":"Renewex.Parser.html#__struct__/0"},{"type":"function","title":"Renewex.Parser.detect_and_parse_document/1","doc":"For a given list of tokens deduce that grammar version automatically and use \r\nit to parse the complete token stream.","ref":"Renewex.Parser.html#detect_and_parse_document/1"},{"type":"function","title":"Renewex.Parser.detect_document_version/1","doc":"Constructs a new parser state by taking a list of tokens. The grammar to be used for parsing\r\nIs extract from the version information encoded in the first token.\r\nIf the first token is not an integer it is assumed that the oldest version of Renew had been used to create the file\r\nthat this list of tokens are read from.","ref":"Renewex.Parser.html#detect_document_version/1"},{"type":"function","title":"Renewex.Parser.finalize/1","doc":"Expect the list of tokens to be empty and return the reversed list of parsed objects.\r\nIf the list of tokens is not empty, return an error.","ref":"Renewex.Parser.html#finalize/1"},{"type":"function","title":"Renewex.Parser.get_version/1","doc":"Get the version number of the parsers grammar.","ref":"Renewex.Parser.html#get_version/1"},{"type":"function","title":"Renewex.Parser.is_eof/1","doc":"Check if the list of tokens of the given parser state is empty.","ref":"Renewex.Parser.html#is_eof/1"},{"type":"function","title":"Renewex.Parser.new/2","doc":"Constructs a new parser state for a given list of tokens and a given grammar.","ref":"Renewex.Parser.html#new/2"},{"type":"function","title":"Renewex.Parser.parse_document/2","doc":"Parse the given list of tokens with the given grammar.","ref":"Renewex.Parser.html#parse_document/2"},{"type":"function","title":"Renewex.Parser.parse_grammar_rule/2","doc":"Given a parser state continue parsing by applying the given rule.\r\nThe rule is the name of a java class defined in the parsers grammars hierarchy.\r\n\r\nIn contrast to `parse_storable` no `\"NULL\"` or `\"REF\"` values are allowed and the parsed objects must\r\n*not* be prefixed with its class name. Instead the given rule explicitly determines which grammar rule to use.","ref":"Renewex.Parser.html#parse_grammar_rule/2"},{"type":"function","title":"Renewex.Parser.parse_grammar_rule/3","doc":"","ref":"Renewex.Parser.html#parse_grammar_rule/3"},{"type":"function","title":"Renewex.Parser.parse_list/2","doc":"Parse a list, given the current state of a parser\r\nThe next token must be an integer encoding the length of the list `lst`.\r\nThe given function `fun` is a function that must parse single item of the list.\r\nIt is applied `lst` times in a row.","ref":"Renewex.Parser.html#parse_list/2"},{"type":"function","title":"Renewex.Parser.parse_primitive/2","doc":"Given a current parser state, read a single token of a given primitive type.","ref":"Renewex.Parser.html#parse_primitive/2"},{"type":"function","title":"Renewex.Parser.parse_storable/3","doc":"Given the current parser state, parse the object.\r\nThe object is expected to be either NULL or a REF token or a serialized java class prefixed\r\nwith its class name as next token. This prefix determines which grammar rule is used to continue parsing\r\nthe list of tokens.\r\n\r\nIf a serialized java object is read, it is prepedned to the ref_map of the parser.\r\nYou can choose for this function to then eiter return a reference into this ref_map as integer (default)\r\nor to return the parsed object Storable struct itself (set `return_ref` to true).\r\n\r\nWhen `expected_type` is given the parsed object is required to be a subtype of the `expected_type` accordings to the grammars\r\nclass hierarhy.","ref":"Renewex.Parser.html#parse_storable/3"},{"type":"function","title":"Renewex.Parser.skip_any/1","doc":"Given the current state of a parser skip the next token. If list of tokens is already empty return an error.","ref":"Renewex.Parser.html#skip_any/1"},{"type":"function","title":"Renewex.Parser.skip_any/2","doc":"Given the current state of a parser expect the next tokens type to be one of the given types. Then skip it.\r\nIf list of tokens already empty or the types do not match, return an error","ref":"Renewex.Parser.html#skip_any/2"},{"type":"function","title":"Renewex.Parser.try_parse/2","doc":"Try to read multiple tokes of given `types` at once.","ref":"Renewex.Parser.html#try_parse/2"},{"type":"function","title":"Parameters - Renewex.Parser.try_parse/2","doc":"- `parser`: The current parser state\r\n- `types`: A list of token types to read on sequence.","ref":"Renewex.Parser.html#try_parse/2-parameters"},{"type":"function","title":"Returns - Renewex.Parser.try_parse/2","doc":"Either `{tokens, new_parser}` with `tokens` being a list of successfully read tokens.\r\nOr `{:none, parser}` if the expected sequency of tokens could not been read.","ref":"Renewex.Parser.html#try_parse/2-returns"},{"type":"function","title":"Renewex.Parser.try_skip/2","doc":"Skip a sequence of tokens of given `skip_types`.","ref":"Renewex.Parser.html#try_skip/2"},{"type":"module","title":"Renewex.Serializer","doc":"This module implements the core of the serializer for generating [Renew](http://renew.de) `*.rnw` files.\r\nThe grammar to be used for serialization is defined by `Renewex.Grammar`.\r\n\r\nThe counter part for reading/parsing [Renew](http://renew.de) `*.rnw` files is defined in `Renewex.Parser`.\r\n\r\nThis `Renewex.Serializer` manages the overall serializer state and provides function for converting \r\n`Renewex.Storable.__struct__/0` structs into strings.","ref":"Renewex.Serializer.html"},{"type":"function","title":"Renewex.Serializer.__struct__/0","doc":"The state of the serializer consists of 4 fields:\r\n\r\n- `grammar`: The grammar definition to be used for serialization.\r\n- `refs`: The list of all `Renewex.Storable.__struct__/0`s that might take part the serialization process. \r\n  This list is used to allow `Renewex.Storable.__struct__/0`s to reference each other via index into this list. \r\n  This may occure because the [Renew](http://renew.de) file format is based a Java object graph that might\r\n  contain cyclic references.\r\n- `used_refs`: A map to mark already serialized references. Any given `Renewex.Storable.__struct__/0` is serialized \r\n  the first time it occures during the serialization process. \r\n  Afterwards it is back referenced via integer index pointing at its first occurence. \r\n  The `used_refs` map keeps track of already serialized references and their corresponding index.\r\n- `output`: An iolist into which the result of the serialization is accumulated.","ref":"Renewex.Serializer.html#__struct__/0"},{"type":"function","title":"Renewex.Serializer.append_token/2","doc":"Appends some token to the output of the serializer.","ref":"Renewex.Serializer.html#append_token/2"},{"type":"function","title":"Parameters - Renewex.Serializer.append_token/2","doc":"- `serializer`: The serializer to which output to append the token.\r\n- `token`: `{type, value}` tuple representing the token to append.\r\n\r\n# Returns\r\nThe serializer with the appended output.","ref":"Renewex.Serializer.html#append_token/2-parameters"},{"type":"function","title":"Renewex.Serializer.get_output_string/1","doc":"Retreive the accumulated output of the serializer as binary string.","ref":"Renewex.Serializer.html#get_output_string/1"},{"type":"function","title":"Parameters - Renewex.Serializer.get_output_string/1","doc":"- `serializer_or_ok_serializer`: A tuple `{:ok, serializer}` or the `serializer` to get the output from.","ref":"Renewex.Serializer.html#get_output_string/1-parameters"},{"type":"function","title":"Returns - Renewex.Serializer.get_output_string/1","doc":"The result of the serialization as binary string.","ref":"Renewex.Serializer.html#get_output_string/1-returns"},{"type":"function","title":"Renewex.Serializer.new/2","doc":"Initiliaze a serializer state from a list of `refs` and a `grammar` definition.","ref":"Renewex.Serializer.html#new/2"},{"type":"function","title":"Parameters: - Renewex.Serializer.new/2","doc":"- `refs`: A list of `Renewex.Storable.__struct__/0` that might reference each other via index into this list.\r\n- `grammar`: The grammar definition be used for serialization.\r\n\r\n# Returns\r\nA fresh `%Serializer{}` struct with empty output and no used refs.","ref":"Renewex.Serializer.html#new/2-parameters"},{"type":"function","title":"Renewex.Serializer.prepend_token/2","doc":"Prepends some token to the output of the serializer.","ref":"Renewex.Serializer.html#prepend_token/2"},{"type":"function","title":"Parameters - Renewex.Serializer.prepend_token/2","doc":"- `serializer`: The serializer to which output to prepend the token.\r\n- `token`: `{type, value}` tuple representing the token to prepend.\r\n\r\n# Returns\r\nThe serializer with the prepended output.","ref":"Renewex.Serializer.html#prepend_token/2-parameters"},{"type":"function","title":"Renewex.Serializer.serialize_grammar_rule/3","doc":"Serialize a map of `fields` according to the grammar `rule` into the `serializer`.","ref":"Renewex.Serializer.html#serialize_grammar_rule/3"},{"type":"function","title":"Parameters - Renewex.Serializer.serialize_grammar_rule/3","doc":"- `serializer`: The serializer to write the result into.\r\n- `rule`: The name of the grammar rule to use (the grammar definition itself comes from the serializer).\r\n- `fields`: The map containing the data to be serialized.","ref":"Renewex.Serializer.html#serialize_grammar_rule/3-parameters"},{"type":"function","title":"Returns - Renewex.Serializer.serialize_grammar_rule/3","doc":"Either a tuple `{:ok, serializer}` with the serialized data appended to the `serializer`s outout if successful.\r\nOr `{:error, reason}` if the serialization failed for some `reason`.","ref":"Renewex.Serializer.html#serialize_grammar_rule/3-returns"},{"type":"function","title":"Renewex.Serializer.serialize_list/3","doc":"Serialize a `list` of values according to callback (`ser_fn`) into the `serializer`.","ref":"Renewex.Serializer.html#serialize_list/3"},{"type":"function","title":"Parameters - Renewex.Serializer.serialize_list/3","doc":"- `serializer`: The serializer to write the result into.\r\n- `list`: The list to be serialized\r\n- `ser_fn/2`: The function the defined the serialization of each list item. \r\n  Receives two arguments: `list_item, serializer`, where serializer is the accumulated state of the serializer.","ref":"Renewex.Serializer.html#serialize_list/3-parameters"},{"type":"function","title":"Returns - Renewex.Serializer.serialize_list/3","doc":"Either a tuple `{:ok, serializer}` with the serialized data appended to the `serializer`s outout if successful.\r\nOr `{:error, reason}` if the serialization failed for some `reason`.","ref":"Renewex.Serializer.html#serialize_list/3-returns"},{"type":"function","title":"Renewex.Serializer.serialize_storable/3","doc":"Serialize a `Storable` of `expected_type` into the `serializer`.","ref":"Renewex.Serializer.html#serialize_storable/3"},{"type":"function","title":"Parameters - Renewex.Serializer.serialize_storable/3","doc":"- `serializer`: The serializer to write the result into.\r\n- `storable`: The struct to serialize.\r\n- `expected_type`: The name of a Java class or interface that the storable is expected to be a subtype of. \r\n  See `Renewex.Grammar` for details on how the [Renew](http://renew.de) file format is based on a Java class \r\n  hierarchy that is emulated here.","ref":"Renewex.Serializer.html#serialize_storable/3-parameters"},{"type":"function","title":"Returns - Renewex.Serializer.serialize_storable/3","doc":"Either a tuple `{:ok, serializer}` with the serialized data appended to the `serializer`s outout if successful.\r\nOr `{:error, reason}` if the serialization failed for some `reason`.","ref":"Renewex.Serializer.html#serialize_storable/3-returns"},{"type":"module","title":"Renewex.Storable","doc":"In the original [Renew](http://renew.de) Java implementation a  `*.rnw` is deserialized \r\ninto Java Objects of a variaty of classes.\r\n\r\nEach of these classes implement the Java interface `CH.ifa.draw.util.Storable` that is responsible for reading/writing the token stream.\r\n\r\nThis module defines a struct that captures the result of such a deserialization and reproduces that concept of a Java\r\nclass consisting of various fields.\r\n\r\nThe struct consists of the `class_name` (the fully qualified Java class of the object has has been parsed) and \r\nthe `fields` (a Map of key/value pairs representing the fields and values of the Java class)","ref":"Renewex.Storable.html"},{"type":"function","title":"Renewex.Storable.__struct__/0","doc":"The struct consists of the `class_name` (the fully qualified Java class of the object has has been parsed) and \r\nthe `fields` (a Map of key/value pairs representing the fields and values of the Java class)","ref":"Renewex.Storable.html#__struct__/0"},{"type":"function","title":"Renewex.Storable.new/2","doc":"Returns a new Storable struct representing an object of the given class_name.","ref":"Renewex.Storable.html#new/2"},{"type":"module","title":"Renewex.Tokenizer","doc":"This module implements a simple tokenizer for splitting a string into lexems that are needed to parse [Renew](http://renew.de) `*.rnw` files.\r\n\r\n[Renew](http://renew.de) `*.rnw` files are text files containing a human readable serialization of Renew Java Objects.\r\n\r\nFor reading such a file the text content must first be split into tokens/lexems that are similar to Java tokens.\r\nIn the original  [Renew](http://renew.de) Java implementation the Java tokenizer is used but the Renew file format does not\r\nmake use of all the tokens defined by the Java language. Hence this module defines only a sub set Java syntax tokens.\r\n\r\n`*.rnw` contain an object graph. Each node starts with the name of java class. This class name determines how the following tokens shall be\r\nparsed. Primitive values like integer, float or String are the leaf nodes.\r\nA  `*.rnw` may contain cyclic references. These are represented by `REF  ` tokens that represent a reference to a previously parsed object.\r\nThe   is an index into the array of already parsed objects. For example `REF 5` points to the fifth object that has occured while parsing the file.\r\n\r\nA `REF  ` token must not contain an integer that is larger that the number of already parsed objects, ie. no forward references are possible.","ref":"Renewex.Tokenizer.html"},{"type":"function","title":"Renewex.Tokenizer.cast_value/2","doc":"Converts a given string into a given type.","ref":"Renewex.Tokenizer.html#cast_value/2"},{"type":"function","title":"Parameters - Renewex.Tokenizer.cast_value/2","doc":"- `type`: The type to convert the string into\r\n- `string`: The string to be converted","ref":"Renewex.Tokenizer.html#cast_value/2-parameters"},{"type":"function","title":"Returns - Renewex.Tokenizer.cast_value/2","doc":"The `string` converted into the given `type`","ref":"Renewex.Tokenizer.html#cast_value/2-returns"},{"type":"function","title":"Renewex.Tokenizer.scan/1","doc":"Splits a string it into tokens.\r\n\r\nThe string is expected to be in the format of a [Renew](http://renew.de) `*.rnw` file.","ref":"Renewex.Tokenizer.html#scan/1"},{"type":"function","title":"Parameters - Renewex.Tokenizer.scan/1","doc":"- `input`: The string to be tokenized","ref":"Renewex.Tokenizer.html#scan/1-parameters"},{"type":"function","title":"Returns - Renewex.Tokenizer.scan/1","doc":"A stream of token tuples `{type, value}`. See `Renewex.Tokenizer.token_types` for a list of possible types.","ref":"Renewex.Tokenizer.html#scan/1-returns"},{"type":"function","title":"Renewex.Tokenizer.skip_whitespace/1","doc":"Takes a list of tokens and removes all tokens that are regarded as white space.","ref":"Renewex.Tokenizer.html#skip_whitespace/1"},{"type":"function","title":"Parameters - Renewex.Tokenizer.skip_whitespace/1","doc":"- `tokens`: A stream or list of tokens.","ref":"Renewex.Tokenizer.html#skip_whitespace/1-parameters"},{"type":"function","title":"Returns - Renewex.Tokenizer.skip_whitespace/1","doc":"A list of tokens with all whitespace tokens removed.","ref":"Renewex.Tokenizer.html#skip_whitespace/1-returns"},{"type":"function","title":"Renewex.Tokenizer.token_to_binary/2","doc":"Converts token value of a given type back into the corresponding binary string.","ref":"Renewex.Tokenizer.html#token_to_binary/2"},{"type":"function","title":"Parameters - Renewex.Tokenizer.token_to_binary/2","doc":"- `type`: The type of the token\r\n- `string`: The the value of the token","ref":"Renewex.Tokenizer.html#token_to_binary/2-parameters"},{"type":"function","title":"Returns - Renewex.Tokenizer.token_to_binary/2","doc":"A string representing the given token value","ref":"Renewex.Tokenizer.html#token_to_binary/2-returns"},{"type":"function","title":"Renewex.Tokenizer.token_types/0","doc":"Get the list of token types defined by the tokenizer.","ref":"Renewex.Tokenizer.html#token_types/0"},{"type":"function","title":"Returns - Renewex.Tokenizer.token_types/0","doc":"[:white,:float,:int,:boolean,:null,:ref,:class_name,:string] in order determined by the capture groups in the compiled regex","ref":"Renewex.Tokenizer.html#token_types/0-returns"},{"type":"extras","title":"RenewEx","doc":"# RenewEx\n\n[Renew](http://renew.de/) file parser in Elixir.","ref":"readme.html"},{"type":"extras","title":"Running tests - RenewEx","doc":"All test:\n```sh\nmix test\n```\n\nOnly fast tests:\n```\nmix test --exclude slow\n```","ref":"readme.html#running-tests"},{"type":"extras","title":"Example Usage - RenewEx","doc":"```example.ex\n# Read rnw file\n{:ok, file_content} = File.read(\"example.rnw\")\n\n# Parse file content\n{:ok, %Renewex.Document{} = document} = Renewex.parse_document(file_content)\n\n# Inspect document:\nIO.puts(document.version)\nIO.puts(document.root)\nIO.puts(Enum.count(document.refs))\n\n# Do some work with `document`\n# ...\n\n# serialize document back into string\n{:ok, serialized} = Renewex.serialize_document(document)\n\n# Write rnw file\nFile.write(\"modified.rnw\", serialized)\n```","ref":"readme.html#example-usage"}],"content_type":"text/markdown","producer":{"name":"ex_doc","version":[48,46,51,52,46,50]}}